@@ -141,6 +141,10 @@ class RabbitMqEventConsumer(IEventConsumer):
                     method, properties, body, handler
                 )
                 return
+            else:
+                self.consumer_logger.log(
+                    method, properties, body, handler, log_activity="received_message"
+                )
 
             try:
                 event = Event.from_json(body)
@@ -189,7 +193,13 @@ class RabbitMqEventConsumer(IEventConsumer):
                 ch.basic_ack(delivery_tag=method.delivery_tag)
 
             self.consumer_logger.log(
-                method, properties, body, handler, result, derived_action
+                method,
+                properties,
+                body,
+                handler,
+                "computed_message",
+                result,
+                derived_action,
             )
             self.printer.print_separator()
 
