@@ -1,11 +1,8 @@
-from abc import ABCMeta, abstractmethod
+from abc import abstractmethod, ABC
 from typing import List, Dict
 
 
-class IDatabase:
-
-    __metaclass__ = ABCMeta
-
+class IDatabase(ABC):
     def __init__(self, name: str, models: Dict = None):
         self.name = name
         self.models = models if models else {}
@@ -24,6 +21,10 @@ class IDatabase:
     def delete(self):
         raise NotImplementedError
 
+    @abstractmethod
+    def clear_data(self):
+        raise NotImplementedError
+
     @abstractmethod
     def get_model(self, model_name: str):
         raise NotImplementedError
